## cdist-type__mysql_database(7)

### Benedikt Koeppel

`<code@benediktkoeppel.ch>`

## 1. NAME

cdist-type__mysql_database - Manage a MySQL database

## 2. DESCRIPTION

This cdist type allows you to install a MySQL database.

## 3. REQUIRED PARAMETERS

None.

## 4. OPTIONAL PARAMETERS

name
  The name of the database to install defaults to the object id
user
  A user that should have access to the database
password
  The password for the user who manages the database

## 5. EXAMPLES

    __mysql_database "cdist" --name "cdist" --user "myuser" --password "mypwd"

## 6. SEE ALSO

- cdist-type(7)

## 7. COPYING

Copyright (C) 2012 Benedikt Koeppel. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).